@@ -751,20 +751,26 @@ module Substitutors
               path = refid.chop
             end
             if macro
-              src2src = (path = path.slice 0, path.length - 5) if path.end_with? '.adoc'
-            elsif (last_dot_idx = path.rindex '.') && ASCIIDOC_EXTENSIONS[path.slice last_dot_idx, path.length]
-              src2src = (path = path.slice 0, last_dot_idx)
+              if path.end_with? '.adoc'
+                src2src = path = path.slice 0, path.length - 5
+              elsif !(Helpers.extname? path)
+                src2src = path
+              end
+            elsif path.end_with?(*ASCIIDOC_EXTENSIONS.keys)
+              src2src = path = path.slice 0, (path.rindex '.')
             else
               src2src = path
             end
           else
             target, fragment = refid, (refid.slice 1, refid.length)
           end
-        elsif macro && (refid.include? '.')
+        elsif macro
           if refid.end_with? '.adoc'
-            src2src = (path = refid.slice 0, refid.length - 5)
-          else
+            src2src = path = refid.slice 0, refid.length - 5
+          elsif Helpers.extname? refid
             path = refid
+          else
+            fragment = refid
           end
         else
           fragment = refid
@@ -801,7 +807,7 @@ module Substitutors
           refid, target = fragment, %(##{fragment})
         # handles: Node Title or Reference Text
         # do reverse lookup on fragment if not a known ID and resembles reftext (contains a space or uppercase char)
-        elsif (refid = doc.resolve_id fragment) && ((fragment.include? ' ') || fragment.downcase != fragment)
+        elsif ((fragment.include? ' ') || fragment.downcase != fragment) && (refid = doc.resolve_id fragment)
           fragment, target = refid, %(##{refid})
         else
           refid, target = fragment, %(##{fragment})
